api.cases.v2 package — Argus-Toolbelt 1.0 documentation

# api.cases.v2 package

## Submodules

## api.cases.v2.case module

Autogenerated API

`api.cases.v2.case.` `acknowledge_workflow`(caseID: int, workflow: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Acknowledge workflow on case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID workflow (str) – Workflow to acknowledge
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 433, “limit”: 730, “responseCode”: 200, “count”: 575, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Baby color indicate.”, “messageTemplate”: “Peace property mouth so work.”, “field”: “Wear couple increase part stock my see.”, “parameter”: {}, “timestamp”: 607911746}], “currentPage”: 140, “size”: 995}

`api.cases.v2.case.` `add_attachment`(caseID: int, name: str = None, mimeType: str = None, data: str = None, encryptedZip: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add new attachment (PUBLIC) Upload new attachment as JSON object with base64-encoded data

  Return type: | `dict`

`api.cases.v2.case.` `add_case_link`(caseID: int, linkToCaseID: int, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add link to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – ID of case to link from linkToCaseID (int) – ID of case to link to type (str) – Type of link to add
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 838, “limit”: 12, “responseCode”: 200, “count”: 943, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Increase federal where long institution teacher course mouth.”, “messageTemplate”: “Economy night car effect discuss message fact.”, “field”: “Travel exist author base piece realize question.”, “parameter”: {}, “timestamp”: 264267760}], “currentPage”: 470, “size”: 410}

`api.cases.v2.case.` `add_case_tag`(caseID: int, tags: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add tag to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tags (list) – Add multiple tags as key/value strings or JSON objects
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 338, “limit”: 656, “responseCode”: 200, “count”: 370, “data”: [{“id”: “Tough off too this research size pattern.”, “addedTimestamp”: 314575760, “addedByUser”: {“id”: 501, “customerID”: 863, “userName”: “vwalker”, “name”: “Pamela Park”}, “key”: “By in analysis race toward call particular.”, “value”: “Leg some throughout ready road born.”, “flags”: [“MERGED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Between cost item always.”, “messageTemplate”: “Herself left science line us road.”, “field”: “Standard form develop my none home fast.”, “parameter”: {}, “timestamp”: 937474072}], “currentPage”: 509, “size”: 934}

`api.cases.v2.case.` `add_case_watcher`(caseID: int, subjectID: int = None, destination: str = None, type: str = 'email', verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add watcher to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID subjectID (int) – Subject to add watcher for destination (str) – Contact information to add as watcher (email address or phone number). If subject is specified, this is ignored. type (str) – Type of watcher to add (default email) verbose (bool) – If set, explicitly set verbosity for watcher (will override default settings on subject)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 566, “limit”: 236, “responseCode”: 200, “count”: 348, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hair international capital hospital.”, “messageTemplate”: “Should continue scientist able available.”, “field”: “Religious cut best reduce.”, “parameter”: {}, “timestamp”: 177479874}], “currentPage”: 825, “size”: 575}

`api.cases.v2.case.` `add_comment`(caseID: int, asReplyTo: str = None, comment: str = None, originEmailAddress: str = None, internal: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Submit new comment to case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID asReplyTo (str) – Optional ID of comment to reply to. comment (str) – Comment to add. Html is allowed, will be sanitized. originEmailAddress (str) – If comment is added from an email, specify origin email address here => format:email internal (bool) – If true, mark comment as internal, only visible to service techs. Default is false.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 100, “limit”: 484, “responseCode”: 200, “count”: 573, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Everything letter result tree about none common.”, “messageTemplate”: “Power many nature occur dinner occur.”, “field”: “Visit black before develop what green public same.”, “parameter”: {}, “timestamp”: 749156224}], “currentPage”: 210, “size”: 714}

`api.cases.v2.case.` `advanced_case_search`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, caseID: list = None, type: list = None, service: list = None, category: list = None, status: list = None, priority: list = None, startTimestamp: int = None, endTimestamp: int = None, assetID: list = None, tag: list = None, workflow: list = None, field: list = None, keywords: list = None, timeFieldStrategy: list = None, timeMatchStrategy: str = None, keywordFieldStrategy: list = None, keywordMatchStrategy: str = None, userID: list = None, userFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', userAssigned: bool = 'False', techAssigned: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns cases matching the defined CaseSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. caseID (list) – Restrict search to specific cases (by ID). type (list) – Restrict search to entries of one of these types. service (list) – Restrict search to entries of one of these services (by service shortname or ID). category (list) – Restrict search to entries of one of these categories (by category shortname or ID). status (list) – Restrict search to entries of one of these statuses. priority (list) – Restrict search to entries with given priorties startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). assetID (list) – Restrict search to cases associated with specified assets (hosts, services or processes) tag (list) – Restrict search to entries matching the given tag criteria. workflow (list) – Restrict search to entries matching the given workflow criteria. field (list) – Restrict search to entries matching the given field criteria. keywords (list) – Search for keywords. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). userID (list) – Restrict search to cases associated with these users. userFieldStrategy (list) – Defines which user fields will be searched (default match all user fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). userAssigned (bool) – If set, limit search to cases where assignedUser field is set/unset techAssigned (bool) – If set, limit search to cases where assignedTech field is set/unset
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 47, “limit”: 374, “responseCode”: 200, “count”: 706, “data”: [{“id”: 468, “initialStatus”: “pendingClose”, “status”: “workingSoc”, “initialPriority”: “high”, “priority”: “critical”, “subject”: “Weight data PM or.”, “description”: “During make game center radio.”, “customerReference”: “Customer let suggest recently.”, “accessMode”: “readRestricted”, “reporter”: {“id”: 292, “customerID”: 218, “userName”: “gary51”, “name”: “Mr. Aaron Soto”}, “assignedUser”: {“id”: 382, “customerID”: 130, “userName”: “laurenwilliams”, “name”: “Kathy Nguyen”}, “assignedTech”: {“id”: 914, “customerID”: 999, “userName”: “mallorytaylor”, “name”: “Ronald Brown”}, “createdTimestamp”: 958748709, “createdByUser”: {“id”: 386, “customerID”: 322, “userName”: “ymorrison”, “name”: “Robin Vargas”}, “lastUpdatedTimestamp”: 1138912378, “lastUpdatedByUser”: {“id”: 683, “customerID”: 604, “userName”: “castillojacqueline”, “name”: “Charles Grant”}, “closedTimestamp”: 815823240, “closedByUser”: {“id”: 545, “customerID”: 581, “userName”: “heathersmith”, “name”: “James Ferrell”}, “publishedTimestamp”: 394694923, “publishedByUser”: {“id”: 991, “customerID”: 779, “userName”: “znelson”, “name”: “Julie Montgomery”}, “flags”: [“DEFAULT_CONTACTS”], “properties”: {“additionalProperties”: “Tough manage size business team remember present.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Anything interest difference measure threat surface.”, “messageTemplate”: “Improve image section.”, “field”: “How life who off into from production onto.”, “parameter”: {}, “timestamp”: 747658865}], “currentPage”: 695, “size”: 495}

`api.cases.v2.case.` `change_access_settings`(caseID: int, accessMode: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Change general access settings (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID accessMode (str) – If set, this will alter the access mode of the case.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 449, “limit”: 870, “responseCode”: 200, “count”: 801, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Heavy budget every look result.”, “messageTemplate”: “Whole pretty market parent.”, “field”: “Traditional study win country easy break.”, “parameter”: {}, “timestamp”: 1220694237}], “currentPage”: 816, “size”: 80}

`api.cases.v2.case.` `close_case`(caseID: int, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Close an open case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID comment (str) – Closing comment to add to case. May use HTML, will be sanitized.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 93, “limit”: 115, “responseCode”: 200, “count”: 76, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Believe guy wear order water task international.”, “messageTemplate”: “View girl south owner time ready.”, “field”: “Consider land voice anything artist.”, “parameter”: {}, “timestamp”: 132538755}], “currentPage”: 792, “size”: 602}

`api.cases.v2.case.` `create_case`(service: str = None, category: str = None, type: str = None, status: str = None, watchers: list = None, fields: list = None, subject: str = None, description: str = None, customerReference: str = None, aclMembers: list = None, originEmailAddress: str = None, publish: bool = 'True', defaultWatchers: bool = 'True', priority: str = 'medium', accessMode: str = 'roleBased', customerID: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new case defined by CaseCreateRequest (PUBLIC)

  Return type: | `dict`
  Parameters: | service (str) – ID of service to create case for category (str) – If set, assign given category to new case (by category shortname). type (str) – Type of case to create status (str) – Status of case to create. If not set, system will select automatically. watchers (list) – Explicit watchers to add to this case. fields (list) – Fields to set on case creation. Fields in the policy for requested service and customer specifies fields available. If any of the fields in the policy are required on create, and do not have a default value,those fields must be set in the case create request, or the request will fail. subject (str) – Subject of case to create. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Case description. May use HTML, which will be sanitized. customerReference (str) – Customer reference for case. => [sw{}$-().[]“‘_/,*+#:@!?;]* aclMembers (list) – Explicit ACL members to add to case. originEmailAddress (str) – If case is created from an email, specify origin email address here => format:email publish (bool) – Whether to publish new case. Creating an unpublished case requires special permission. (default true) defaultWatchers (bool) – Whether to enable default watchers for this case. If set to false, default watchers will not be enabled, and will not be notified upon creation of this case. (default true) priority (str) – Priority of case to create. (default medium) accessMode (str) – Access mode for new case. (default roleBased) customerID (int) – ID of customer to create case for (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 765, “limit”: 527, “responseCode”: 200, “count”: 430, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Explain Mrs thing smile main positive growth.”, “messageTemplate”: “Laugh per organization seat word while research.”, “field”: “Above present to among somebody.”, “parameter”: {}, “timestamp”: 1390059739}], “currentPage”: 126, “size”: 624}

`api.cases.v2.case.` `current_user_watcher_status`(caseID: int, email: bool = 'False', sms: bool = 'False', verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Query and set watcher status for the current user on this case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID email (bool) – If true, enable email notification for current user. If false, disable email. Default is no change. sms (bool) – If true, enable SMS notification for current user. If false, disable SMS. Default is no change. verbose (bool) – If set, explicitly set verbosity for watcher for enabled contact methods (will override default settings on current user)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 170, “limit”: 51, “responseCode”: 200, “count”: 705, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Try imagine back fill night budget.”, “messageTemplate”: “Note political moment western coach available action.”, “field”: “Agreement significant according laugh must.”, “parameter”: {}, “timestamp”: 926916014}], “currentPage”: 767, “size”: 422}

`api.cases.v2.case.` `delete_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete specified attachment from case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID attachmentID (str) – Attachment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 557, “limit”: 443, “responseCode”: 200, “count”: 773, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Public sing one blue agree now within.”, “messageTemplate”: “Shoulder loss sea series argue toward.”, “field”: “Black benefit wind hard.”, “parameter”: {}, “timestamp”: 432911088}], “currentPage”: 885, “size”: 840}

`api.cases.v2.case.` `delete_case`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark existing case as deleted (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 643, “limit”: 325, “responseCode”: 200, “count”: 445, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Store it she place prove.”, “messageTemplate”: “Behavior baby miss however next.”, “field”: “Behavior discuss nation American.”, “parameter”: {}, “timestamp”: 984273341}], “currentPage”: 865, “size”: 58}

`api.cases.v2.case.` `delete_case_link`(caseID: int, linkID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing case link (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID linkID (str) – Link ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 795, “limit”: 90, “responseCode”: 200, “count”: 986, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Attack current major can race player ahead.”, “messageTemplate”: “Night up act together remain student.”, “field”: “Clearly occur after cold state item this.”, “parameter”: {}, “timestamp”: 935250309}], “currentPage”: 87, “size”: 252}

`api.cases.v2.case.` `delete_comment`(caseID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Mark existing comment as deleted (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 747, “limit”: 253, “responseCode”: 200, “count”: 157, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Note also many task factor purpose.”, “messageTemplate”: “Determine particularly watch citizen personal happy herself.”, “field”: “Well bed environmental consider feel read.”, “parameter”: {}, “timestamp”: 1378179819}], “currentPage”: 875, “size”: 51}

`api.cases.v2.case.` `download_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Download specific attachment contents. (PUBLIC) Returns data stream with the attachments mimetype, and attachment disposition with filename. Use /cases/v1/case/{caseID}/attachments/{attachmentID} to fetch metadata about this attachment.

  Return type: | `dict`

`api.cases.v2.case.` `edit_comment`(caseID: int, commentID: str, comment: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Edit existing comment (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID comment (str) – Updated comment
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 69, “limit”: 557, “responseCode”: 200, “count”: 21, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “This age people eat carry parent.”, “messageTemplate”: “Health air affect need Democrat offer run.”, “field”: “Different agency behavior key candidate.”, “parameter”: {}, “timestamp”: 7956720}], “currentPage”: 615, “size”: 344}

`api.cases.v2.case.` `get_attachment`(caseID: int, attachmentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specific attachment metadata (PUBLIC) Use /cases/v1/case/{caseID}/attachments/{attachmentID}/download to download attachment contents.

  Return type: | `dict`

`api.cases.v2.case.` `get_case_comment`(caseID: int, commentID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch specific comment (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID commentID (str) – Comment ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 79, “limit”: 324, “responseCode”: 200, “count”: 586, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Keep final full six.”, “messageTemplate”: “Choose life page benefit writer kind.”, “field”: “Power throughout spring because alone up.”, “parameter”: {}, “timestamp”: 1050231119}], “currentPage”: 961, “size”: 818}

`api.cases.v2.case.` `get_case_metadata_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns the basic case descriptor for the case identified by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 963, “limit”: 900, “responseCode”: 200, “count”: 630, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Box successful international likely Republican.”, “messageTemplate”: “Crime candidate major military into.”, “field”: “Writer nor institution.”, “parameter”: {}, “timestamp”: 605895776}], “currentPage”: 279, “size”: 198}

`api.cases.v2.case.` `grant_access`(caseID: int, subjectID: int = None, level: str = 'read', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Grant access to a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID subjectID (int) – ID of subject (user or group) to grant access to. level (str) – Level to grant for subject. (default read)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 284, “limit”: 431, “responseCode”: 200, “count”: 908, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Night consumer kitchen community paper.”, “messageTemplate”: “Citizen middle than we book police.”, “field”: “Join ever question use.”, “parameter”: {}, “timestamp”: 884092342}], “currentPage”: 678, “size”: 332}

`api.cases.v2.case.` `list_case_a_c_l`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List ACL entries for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 267, “limit”: 943, “responseCode”: 200, “count”: 620, “data”: [{“id”: “Investment wife federal.”, “addedTimestamp”: 253452639, “addedByUser”: {“id”: 885, “customerID”: 258, “userName”: “icampos”, “name”: “Elizabeth Hampton”}, “grantedSubject”: {“id”: 538, “customerID”: 396, “name”: “Richard Ortiz”}, “flags”: [“DELETED”], “level”: “owner”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Analysis executive somebody run.”, “messageTemplate”: “Stop evidence do one network development.”, “field”: “Short pretty bit your size.”, “parameter”: {}, “timestamp”: 701890473}], “currentPage”: 820, “size”: 184}

`api.cases.v2.case.` `list_case_attachments`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List attachments for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 870, “limit”: 575, “responseCode”: 200, “count”: 987, “data”: [{“id”: “Under window story person she last set.”, “addedTimestamp”: 1343738547, “addedByUser”: {“id”: 88, “customerID”: 517, “userName”: “esingh”, “name”: “John Sutton”}, “name”: “Kelly Davis”, “mimeType”: “And administration apply they.”, “flags”: [“MERGED”], “size”: 70}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Base loss around wonder travel.”, “messageTemplate”: “Have rich suggest anyone wall high pretty.”, “field”: “Oil TV side also beautiful increase sound.”, “parameter”: {}, “timestamp”: 190354843}], “currentPage”: 405, “size”: 135}

`api.cases.v2.case.` `list_case_comments`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List comments for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 753, “limit”: 353, “responseCode”: 200, “count”: 862, “data”: [{“id”: “Current sport will book.”, “addedTimestamp”: 41097678, “addedByUser”: {“id”: 970, “customerID”: 641, “userName”: “asoto”, “name”: “Roger Mann”}, “comment”: “Two yes operation drug relate.”, “reference”: “Enough two find human.”, “flags”: [“DELETED”], “status”: “pendingClose”, “priority”: “critical”, “properties”: {“additionalProperties”: “Science factor born thus political against explain.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “He expert wrong way gun attack moment.”, “messageTemplate”: “Home always act despite.”, “field”: “Suggest prevent least event identify receive apply.”, “parameter”: {}, “timestamp”: 1076123041}], “currentPage”: 532, “size”: 140}

`api.cases.v2.case.` `list_case_history`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List change events for an existing case. This endpoint is not implemented yet. (DEV)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 679, “limit”: 86, “responseCode”: 200, “count”: 912, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Tough return score house win.”, “messageTemplate”: “Likely most report test.”, “field”: “By continue senior try word decision.”, “parameter”: {}, “timestamp”: 151267520}], “currentPage”: 473, “size”: 60}

`api.cases.v2.case.` `list_case_links`(caseID: int, direction: str = None, type: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List links for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID direction (str) – Specify direction of links to fetch (default all) type (list) – Specify link types to fetch (default all) offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 507, “limit”: 579, “responseCode”: 200, “count”: 538, “data”: [{“id”: “And return level without.”, “addedTimestamp”: 576099942, “addedByUser”: {“id”: 879, “customerID”: 420, “userName”: “elizabeth51”, “name”: “Micheal Lopez”}, “flags”: [“DELETED”], “direction”: “outgoing”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Suffer third computer there.”, “messageTemplate”: “Edge Democrat responsibility wait.”, “field”: “Perhaps see perform board.”, “parameter”: {}, “timestamp”: 1125218257}], “currentPage”: 944, “size”: 58}

`api.cases.v2.case.` `list_case_tags`(caseID: int, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List tags for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 364, “limit”: 109, “responseCode”: 200, “count”: 814, “data”: [{“id”: “Want central probably.”, “addedTimestamp”: 985213986, “addedByUser”: {“id”: 222, “customerID”: 810, “userName”: “vmurphy”, “name”: “David Freeman”}, “key”: “Movement key land hope six perform only.”, “value”: “You hospital compare.”, “flags”: [“MERGED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Mrs language where mission board entire.”, “messageTemplate”: “Middle for civil spend agent music once work.”, “field”: “Fear size music edge.”, “parameter”: {}, “timestamp”: 1409344043}], “currentPage”: 55, “size”: 218}

`api.cases.v2.case.` `list_case_watchers`(caseID: int, offset: int = 0, limit: int = 25, includeExplicit: bool = 'True', includeDefault: bool = 'True', includeDisabled: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List watchers for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID offset (int) – Skip a number of results limit (int) – Maximum number of returned results includeExplicit (bool) – Include explicit watchers (default true) includeDefault (bool) – Include default watchers (default true) includeDisabled (bool) – Include disabled watchers (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 886, “limit”: 979, “responseCode”: 200, “count”: 384, “data”: [{“id”: “Authority parent recognize example available matter.”, “addedTimestamp”: 1045658925, “addedByUser”: {“id”: 702, “customerID”: 177, “userName”: “kristy96”, “name”: “Brittany Warren”}, “flags”: [“MERGED”], “subject”: {“id”: 622, “customerID”: 342, “name”: “Dr. Elizabeth Taylor”}, “contactID”: 941, “role”: “watcher”, “destination”: “Act study strategy.”, “minimumPriority”: “medium”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Beat mother attorney rather.”, “messageTemplate”: “Choice include them.”, “field”: “Act traditional just build business southern generation surface.”, “parameter”: {}, “timestamp”: 1387617135}], “currentPage”: 33, “size”: 755}

`api.cases.v2.case.` `list_workflows`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List workflows for an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 944, “limit”: 579, “responseCode”: 200, “count”: 132, “data”: [{“id”: “Child capital nothing later forward cause state benefit.”, “addedTimestamp”: 316899302, “addedByUser”: {“id”: 403, “customerID”: 162, “userName”: “jpatel”, “name”: “Randy Beck”}, “workflow”: “customerUpdate”, “acknowledgedByUser”: {“id”: 807, “customerID”: 876, “userName”: “smithkevin”, “name”: “Gabriel Taylor”}, “acknowledgedTimestamp”: 69799872, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Understand anyone wall man charge less.”, “messageTemplate”: “Wind save treat mention smile successful light.”, “field”: “War policy carry red those red style late.”, “parameter”: {}, “timestamp”: 151663063}], “currentPage”: 516, “size”: 563}

`api.cases.v2.case.` `merge_cases`(mergeInto: int, mergeFrom: int, description: str = None, priority: str = None, status: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Merge two cases (PUBLIC) This will merge the contents of the mergeFrom case into the mergeInto case.The mergeFrom case will be marked as deleted/merged, and the mergeInto case will continue to exist, but with entries and attachments from the mergeFrom case embedded into it.If nothing else is specified, the status and priority of the mergeInto case will be retained.

  Return type: | `dict`

`api.cases.v2.case.` `move_case`(id: int, customerID: int = None, service: str = None, category: str = None, type: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Move a case to a differnet category, service or customer (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID customerID (int) – If set, move case to specified customer. service (str) – If set, move case to specified service. category (str) – If set, assign given category to specified category (by category shortname). Set value to empty string to unset category. type (str) – If set, move case to specified type.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 285, “limit”: 78, “responseCode”: 200, “count”: 753, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Pay base him make special become maintain.”, “messageTemplate”: “Happy everybody sister choose.”, “field”: “Become star them drive cost vote election.”, “parameter”: {}, “timestamp”: 713330972}], “currentPage”: 347, “size”: 749}

`api.cases.v2.case.` `publish_case`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Publish existing case not marked as published (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 600, “limit”: 578, “responseCode”: 200, “count”: 766, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Various meet Democrat husband.”, “messageTemplate”: “Husband property act business toward federal contain.”, “field”: “Easy care try its little senior share.”, “parameter”: {}, “timestamp”: 1199197739}], “currentPage”: 417, “size”: 782}

`api.cases.v2.case.` `remove_access`(caseID: int, aclEntryID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Revoke access from a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID aclEntryID (str) – ACL entry to revoke
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 360, “limit”: 52, “responseCode”: 200, “count”: 917, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Else standard data often full drug.”, “messageTemplate”: “Citizen understand not usually term factor music quality.”, “field”: “Development size sometimes gas say.”, “parameter”: {}, “timestamp”: 114528955}], “currentPage”: 532, “size”: 220}

`api.cases.v2.case.` `remove_case_contact_watcher`(caseID: int, contactID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove a specific contact listed in the default watchers from watching this case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID contactID (int) – Contact ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 682, “limit”: 828, “responseCode”: 200, “count”: 277, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Focus director before scene teach.”, “messageTemplate”: “National view administration game town pass college.”, “field”: “Speak red would president executive more.”, “parameter”: {}, “timestamp”: 1122243132}], “currentPage”: 330, “size”: 334}

`api.cases.v2.case.` `remove_case_tag_by_id`(caseID: int, tagID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing tag (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tagID (str) – Tag ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 408, “limit”: 547, “responseCode”: 200, “count”: 236, “data”: [{“id”: “Know not nothing edge.”, “addedTimestamp”: 671392523, “addedByUser”: {“id”: 165, “customerID”: 56, “userName”: “virginia80”, “name”: “Elizabeth Williams”}, “key”: “Race six no describe win part movie.”, “value”: “Parent project us represent can heavy least.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Not reduce firm.”, “messageTemplate”: “Keep point speak year ask data structure.”, “field”: “From treatment draw bar talk similar.”, “parameter”: {}, “timestamp”: 106707937}], “currentPage”: 635, “size”: 946}

`api.cases.v2.case.` `remove_case_tag_by_key_value`(caseID: int, tagKey: str, tagValue: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove existing tag (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID tagKey (str) – Tag Key tagValue (str) – Tag Value
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 604, “limit”: 306, “responseCode”: 200, “count”: 942, “data”: [{“id”: “Country different kind sound wrong us story.”, “addedTimestamp”: 276985505, “addedByUser”: {“id”: 594, “customerID”: 719, “userName”: “tiffany64”, “name”: “Tamara Moore”}, “key”: “Could teach growth factor meeting family poor.”, “value”: “Still audience situation agency.”, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Try often debate whole.”, “messageTemplate”: “Money author group especially.”, “field”: “Per more western interesting.”, “parameter”: {}, “timestamp”: 691710921}], “currentPage”: 621, “size”: 914}

`api.cases.v2.case.` `remove_case_watcher`(caseID: int, watcherID: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove specific watcher from a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID watcherID (str) – Watcher ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 538, “limit”: 981, “responseCode”: 200, “count”: 229, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Second contain main huge Mrs structure.”, “messageTemplate”: “Hotel check along name often organization.”, “field”: “Collection part land for her.”, “parameter”: {}, “timestamp”: 1474310408}], “currentPage”: 147, “size”: 792}

`api.cases.v2.case.` `remove_current_user_watcher`(caseID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove the current user from the watchlist of this case.If the currentuser is a contact, this will override the contact settings for the current user for this case. (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 801, “limit”: 315, “responseCode”: 200, “count”: 624, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Information call pass company final information organization.”, “messageTemplate”: “Mean general ahead human effect rich husband onto.”, “field”: “Crime without call nature.”, “parameter”: {}, “timestamp”: 1293774827}], “currentPage”: 108, “size”: 534}

`api.cases.v2.case.` `request_workflow`(caseID: int, workflow: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request new workflow on case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID workflow (str) – Workflow to request
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 927, “limit”: 520, “responseCode”: 200, “count”: 741, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Relationship blood form true.”, “messageTemplate”: “Sit improve over run lot leave lose one.”, “field”: “Four the until day likely group.”, “parameter”: {}, “timestamp”: 21296286}], “currentPage”: 920, “size”: 839}

`api.cases.v2.case.` `search_case_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, caseID: list = None, type: list = None, service: list = None, category: list = None, status: list = None, priority: list = None, startTimestamp: int = None, endTimestamp: int = None, assetID: list = None, tag: list = None, workflow: list = None, field: list = None, keywords: list = None, timeFieldStrategy: list = None, timeMatchStrategy: str = None, keywordFieldStrategy: list = None, keywordMatchStrategy: str = None, userID: list = None, userFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', userAssigned: bool = 'False', techAssigned: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns statistics data matching the defined CaseStatsSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. caseID (list) – Restrict search to specific cases (by ID). type (list) – Restrict search to entries of one of these types. service (list) – Restrict search to entries of one of these services (by service shortname or ID). category (list) – Restrict search to entries of one of these categories (by category shortname or ID). status (list) – Restrict search to entries of one of these statuses. priority (list) – Restrict search to entries with given priorties startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). assetID (list) – Restrict search to cases associated with specified assets (hosts, services or processes) tag (list) – Restrict search to entries matching the given tag criteria. workflow (list) – Restrict search to entries matching the given workflow criteria. field (list) – Restrict search to entries matching the given field criteria. keywords (list) – Search for keywords. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). userID (list) – Restrict search to cases associated with these users. userFieldStrategy (list) – Defines which user fields will be searched (default match all user fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default created) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default created) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). userAssigned (bool) – If set, limit search to cases where assignedUser field is set/unset techAssigned (bool) – If set, limit search to cases where assignedTech field is set/unset includeOthers (bool) – If reduce (cutoff>0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 955, “limit”: 163, “responseCode”: 200, “count”: 861, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Age land during today thousand tax throw be.”, “messageTemplate”: “Until and understand us section personal.”, “field”: “Be risk late find.”, “parameter”: {}, “timestamp”: 793809343}], “currentPage”: 625, “size”: 526}

`api.cases.v2.case.` `simple_case_search`(customerID: list = None, service: list = None, status: list = None, type: list = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns cases matching the query parameters (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit result to specified customers service (list) – Limit result to specified services (service shortname) status (list) – Limit result to specified statuses type (list) – Limit result to specified types keywords (list) – Search by keywords offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 734, “limit”: 813, “responseCode”: 200, “count”: 974, “data”: [{“id”: 312, “initialStatus”: “workingCustomer”, “status”: “workingSoc”, “initialPriority”: “low”, “priority”: “critical”, “subject”: “Top his head well.”, “description”: “Mind must home today matter pressure.”, “customerReference”: “Mrs whatever teacher look.”, “accessMode”: “explicit”, “reporter”: {“id”: 714, “customerID”: 36, “userName”: “gibsonelizabeth”, “name”: “Virginia Lutz”}, “assignedUser”: {“id”: 852, “customerID”: 860, “userName”: “christopher59”, “name”: “Jesse Kim”}, “assignedTech”: {“id”: 217, “customerID”: 23, “userName”: “isummers”, “name”: “Mary Ferguson”}, “createdTimestamp”: 1336664783, “createdByUser”: {“id”: 641, “customerID”: 653, “userName”: “johnny35”, “name”: “Carlos Frost”}, “lastUpdatedTimestamp”: 1259137681, “lastUpdatedByUser”: {“id”: 115, “customerID”: 841, “userName”: “jeffrey37”, “name”: “Cheryl Smith”}, “closedTimestamp”: 955036730, “closedByUser”: {“id”: 264, “customerID”: 978, “userName”: “ryanbrian”, “name”: “Christopher Taylor”}, “publishedTimestamp”: 1320663900, “publishedByUser”: {“id”: 498, “customerID”: 568, “userName”: “ebonyjohnson”, “name”: “Melanie Richards”}, “flags”: [“MERGED”], “properties”: {“additionalProperties”: “Quite thank live people magazine about kitchen.”}}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Cold rock letter lose everybody involve.”, “messageTemplate”: “Stuff information for stage five sport.”, “field”: “Kid north successful collection mother.”, “parameter”: {}, “timestamp”: 169286759}], “currentPage”: 154, “size”: 2}

`api.cases.v2.case.` `update_case`(id: int, subject: str = None, description: str = None, status: str = None, priority: str = None, category: str = None, reporterID: int = None, assignedUserID: int = None, assignedTechID: int = None, customerReference: str = None, comment: str = None, originEmailAddress: str = None, internalComment: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request changes to basic fields of an existing case (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Case ID subject (str) – If set, change subject of case. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – If set, change description of case. May use HTML, will be sanitized. status (str) – If set, change status of case priority (str) – If set, change priority of case. category (str) – If set, assign given category to specified category (by category shortname). Set value to empty string to unset category. reporterID (int) – If set, set given user as reporter for case. assignedUserID (int) – If set, assign given user to case. assignedTechID (int) – If set, assign given technical user (solution engineer) to case. customerReference (str) – If set, change customer reference for case. => [sw{}$-().[]“‘_/,*+#:@!?;]* comment (str) – If set, add comment to case. May use HTML, will be sanitized. originEmailAddress (str) – If update is made from an email, specify origin email address here => format:email internalComment (bool) – If true, add comment as internal.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 205, “limit”: 831, “responseCode”: 200, “count”: 437, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Opportunity despite manager season movie role.”, “messageTemplate”: “Stop class not mean beyond blood.”, “field”: “Answer stop government half per decision hit.”, “parameter”: {}, “timestamp”: 17204393}], “currentPage”: 514, “size”: 802}

`api.cases.v2.case.` `update_case_watcher`(caseID: int, watcherID: str, verbose: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update settings for a specific watcher on a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID watcherID (str) – Watcher ID verbose (bool) – If set, will enable/disable verbose status for this watcher.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 12, “limit”: 415, “responseCode”: 200, “count”: 757, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Write style provide fund practice.”, “messageTemplate”: “Those night tell structure hold however left.”, “field”: “Voice record kid difference yeah whole scene.”, “parameter”: {}, “timestamp”: 372589232}], “currentPage”: 113, “size”: 284}

`api.cases.v2.case.` `update_watcher_settings`(caseID: int, defaultWatchers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update general watcher settings on a case (PUBLIC)

  Return type: | `dict`
  Parameters: | caseID (int) – Case ID defaultWatchers (bool) – If set, will enable/disable use of default watchers on this case.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 644, “limit”: 56, “responseCode”: 200, “count”: 944, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Own learn common under policy glass single.”, “messageTemplate”: “Material war both short none.”, “field”: “Finally politics compare no concern act.”, “parameter”: {}, “timestamp”: 1356843325}], “currentPage”: 338, “size”: 710}

## api.cases.v2.category module

Autogenerated API

`api.cases.v2.category.` `create_category`(name: str = None, shortName: str = None, description: str = None, localizedNames: dict = None, domain: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add category (INTERNAL)

  Return type: | `dict`
  Parameters: | name (str) – Descriptive name of category to add. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – Shortname for the category. This value must be unique in domain. => [a-zA-Z0-9_-.]* description (str) – Longer description of this category. => [sw{}$-().[]“‘_/,*+#:@!?;]* localizedNames (dict) – Localized names. If not set, locales will fallback to main name. => [sw{}$-().[]“‘_/,*+#:@!?;]* domain (str) – Name or ID of domain to create this category in.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 902, “limit”: 955, “responseCode”: 200, “count”: 710, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Sometimes my city end.”, “messageTemplate”: “Direction hair professor kind memory free.”, “field”: “Week certain we southern PM its.”, “parameter”: {}, “timestamp”: 363336645}], “currentPage”: 947, “size”: 774}

`api.cases.v2.category.` `delete_category`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Delete category (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID or shortname of category to delete
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 707, “limit”: 67, “responseCode”: 200, “count”: 363, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Argue choose stock information evening box central.”, “messageTemplate”: “Student boy budget final age audience fear particular.”, “field”: “Race sometimes art identify capital if time.”, “parameter”: {}, “timestamp”: 1496472723}], “currentPage”: 651, “size”: 803}

`api.cases.v2.category.` `get_category`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch category (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID or shortname of category to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 992, “limit”: 359, “responseCode”: 200, “count”: 964, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Herself Mr look perhaps too.”, “messageTemplate”: “Other half until as nice what week.”, “field”: “Management cover yourself base.”, “parameter”: {}, “timestamp”: 1284074442}], “currentPage”: 239, “size”: 890}

`api.cases.v2.category.` `list_categories`(id: list = None, shortName: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List categories (INTERNAL)

  Return type: | `dict`
  Parameters: | id (list) – List of category IDs to match shortName (list) – List of category shortnames to match offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 630, “limit”: 441, “responseCode”: 200, “count”: 71, “data”: [{“id”: 46, “name”: “Aaron Johnson”, “shortName”: “About knowledge population exist beyond.”, “description”: “Certain purpose heavy wide animal may successful nation.”, “localizedNames”: {“additionalProperties”: “Can night sound effort wait between expert arm.”}, “createdTimestamp”: 997616763, “createdByUser”: {“id”: 95, “customerID”: 717, “userName”: “gutierrezscott”, “name”: “Lori Franklin”}, “lastUpdatedTimestamp”: 449378940, “lastUpdatedByUser”: {“id”: 278, “customerID”: 811, “userName”: “zachary40”, “name”: “Cynthia Jackson”}, “bindings”: [{“id”: “Success community key local site that.”, “caseTypes”: [“securityIncident”]}], “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Fact field avoid.”, “messageTemplate”: “Any treatment maintain throw court amount.”, “field”: “Action may account total.”, “parameter”: {}, “timestamp”: 367111329}], “currentPage”: 101, “size”: 983}

`api.cases.v2.category.` `search_categories`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, id: list = None, shortName: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search categories (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – id (list) – Limit search to categories with the specified numeric ID`s. shortName (list) – Limit search to categories with the specified shortnames sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 449, “limit”: 671, “responseCode”: 200, “count”: 590, “data”: [{“id”: 534, “name”: “Paige Conley”, “shortName”: “Find go successful cold head.”, “description”: “Catch power everything argue speak.”, “localizedNames”: {“additionalProperties”: “Film story candidate should writer behind understand hot.”}, “createdTimestamp”: 1198994106, “createdByUser”: {“id”: 78, “customerID”: 754, “userName”: “johnporter”, “name”: “Kaylee Rogers”}, “lastUpdatedTimestamp”: 978007281, “lastUpdatedByUser”: {“id”: 642, “customerID”: 195, “userName”: “petersentaylor”, “name”: “William Norton”}, “bindings”: [{“id”: “Friend book assume hot probably.”, “caseTypes”: [“change”]}], “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Result happy class very.”, “messageTemplate”: “Design four better section pay way month consumer.”, “field”: “Mrs serve town style rate accept.”, “parameter”: {}, “timestamp”: 1285276925}], “currentPage”: 452, “size”: 634}

`api.cases.v2.category.` `update_category`(id: str, name: str = None, shortName: str = None, description: str = None, localizedNames: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update category (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID or shortname of category to update name (str) – If set, change the descriptive name for this category. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – If set, change the shortname name for this category. WARNING: This may affect scripts using the category name. => [a-zA-Z0-9_-.]* description (str) – If set, change the long description for this category. => [sw{}$-().[]“‘_/,*+#:@!?;]* localizedNames (dict) – Set localized names to override name for specified language. Only specified languages are changed. => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 401, “limit”: 914, “responseCode”: 200, “count”: 108, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “American there free guy south other.”, “messageTemplate”: “Candidate practice situation check against section.”, “field”: “First hold large citizen single.”, “parameter”: {}, “timestamp”: 854104626}], “currentPage”: 71, “size”: 328}

## api.cases.v2.service module

Autogenerated API

`api.cases.v2.service.` `create_service`(domain: str = None, shortName: str = None, name: str = None, description: str = None, iconURL: str = None, notificationEmail: str = None, caseTypes: list = None, readFunction: str = None, writeFunction: str = None, techFunction: str = None, adminFunction: str = None, defineFunction: str = None, fieldPolicy: str = None, notifyOnCreate: bool = 'False', notifyOnUpdate: bool = 'False', notifyOnClose: bool = 'False', notifyFullFormat: bool = 'False', handledBySoc: bool = 'False', monitoredBySocOutsideOfficeHours: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Define a new service (INTERNAL)

  Return type: | `dict`
  Parameters: | domain (str) – Name or ID of domain to bind service to. shortName (str) – Shortname of service. This must be unique within a domain. => [a-zA-Z0-9_-.]* name (str) – Descriptive name of service. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Longer description of service. => [sw{}$-().[]“‘_/,*+#:@!?;]* iconURL (str) – An image data-URL on the form data:image/png;base64,BASE64IMAGEDATA => Sanitize by regex data:image/.+ notificationEmail (str) – The service notification email address. caseTypes (list) – The case types to enable for this service. readFunction (str) – The name or ID of the function to set as READ function for this service. writeFunction (str) – The name or ID of the function to set as WRITE function for this service. techFunction (str) – The name or ID of the function to set as TECH function for this service. adminFunction (str) – The name or ID of the function to set as ADMIN function for this service. defineFunction (str) – The name or ID of the function to set as DEFINE function for this service. fieldPolicy (str) – The ID of a field policy to set for this service. Default is no policy. notifyOnCreate (bool) – If true, notify the service notification email address on created cases. Default is false. notifyOnUpdate (bool) – If true, notify the service notification email address on updated cases. Default is false. notifyOnClose (bool) – If true, notify the service notification email address on closed cases. Default is false. notifyFullFormat (bool) – If true, use the full format when notifying to the service notification email. Default is false. handledBySoc (bool) – If true, this service is handled by SOC 24/7. Default is false. monitoredBySocOutsideOfficeHours (bool) – If true, this service is monitored by SOC outside office hours. Default is false.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 613, “limit”: 13, “responseCode”: 200, “count”: 710, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Power mission against in always produce.”, “messageTemplate”: “Short pass grow machine.”, “field”: “Consumer deal day.”, “parameter”: {}, “timestamp”: 1206192798}], “currentPage”: 665, “size”: 838}

`api.cases.v2.service.` `get_service`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch service (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – ID or shortname of service
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 366, “limit”: 874, “responseCode”: 200, “count”: 539, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “News statement special successful effect environment.”, “messageTemplate”: “Might thought finish station join picture item.”, “field”: “Especially strategy just particular tough.”, “parameter”: {}, “timestamp”: 118910151}], “currentPage”: 883, “size”: 159}

`api.cases.v2.service.` `list_services`(id: list = None, shortName: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List services (INTERNAL)

  Return type: | `dict`
  Parameters: | id (list) – List of IDs to match shortName (list) – List of shortnames to match offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 286, “limit”: 577, “responseCode”: 200, “count”: 304, “data”: [{“id”: 992, “shortName”: “One final wind administration there.”, “name”: “Mark Velez”, “description”: “Loss put tend interview quite.”, “flags”: [“NOTIFICATION_ON_CREATE”], “logoURL”: “Culture raise enjoy with.”, “notificationEmail”: “Door certain class see involve investment argue direction.”, “createdTimestamp”: 325752247, “createdByUser”: {“id”: 400, “customerID”: 204, “userName”: “matthew89”, “name”: “Dustin Cummings”}, “lastUpdatedTimestamp”: 1489101336, “lastUpdatedByUser”: {“id”: 759, “customerID”: 174, “userName”: “gmiller”, “name”: “Matthew Hunter”}, “caseTypes”: [“securityIncident”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Scene TV key hundred bag role so.”, “messageTemplate”: “Piece foreign true.”, “field”: “Try report woman direction.”, “parameter”: {}, “timestamp”: 43812408}], “currentPage”: 938, “size”: 420}

`api.cases.v2.service.` `search_services`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, id: list = None, shortName: list = None, sortBy: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search services (INTERNAL)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – id (list) – Limit search to services with the specified numeric ID`s. shortName (list) – Limit search to services with the specified shortnames sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 769, “limit”: 714, “responseCode”: 200, “count”: 88, “data”: [{“id”: 915, “shortName”: “Father bring simply possible news easy evidence campaign.”, “name”: “Casey Johnson”, “description”: “Against however enough ten four.”, “flags”: [“DELETED”], “logoURL”: “Maybe those each wish commercial.”, “notificationEmail”: “House fund bag sort country conference.”, “createdTimestamp”: 263436246, “createdByUser”: {“id”: 117, “customerID”: 265, “userName”: “jason83”, “name”: “Jonathan Byrd”}, “lastUpdatedTimestamp”: 442791677, “lastUpdatedByUser”: {“id”: 829, “customerID”: 683, “userName”: “gheath”, “name”: “Kevin Curtis”}, “caseTypes”: [“operationalIncident”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Party today be get interview.”, “messageTemplate”: “Bed case choice investment lawyer nature image.”, “field”: “Song source condition answer minute walk strategy space.”, “parameter”: {}, “timestamp”: 1424335848}], “currentPage”: 59, “size”: 308}

`api.cases.v2.service.` `update_service`(id: str, shortName: str = None, name: str = None, description: str = None, iconURL: str = None, notificationEmail: str = None, caseTypesToAdd: list = None, caseTypesToRemove: list = None, caseTypesToSet: list = None, readFunction: str = None, writeFunction: str = None, techFunction: str = None, adminFunction: str = None, defineFunction: str = None, fieldPolicy: str = None, notifyOnCreate: bool = 'False', notifyOnUpdate: bool = 'False', notifyOnClose: bool = 'False', notifyFullFormat: bool = 'False', handledBySoc: bool = 'False', monitoredBySocOutsideOfficeHours: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update an existing service (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – Service id or shortname shortName (str) – If set, change the shortname of this service. This must be unique within a domain. WARNING: This may affect scripts using shortname as service identifier. => [a-zA-Z0-9_-.]* name (str) – If set, change the descriptive name of the service. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – If set, change the longer description of the service. => [sw{}$-().[]“‘_/,*+#:@!?;]* iconURL (str) – If set, replace the icon for the service. An image data-URL on the form data:image/png;base64,BASE64IMAGEDATA => Sanitize by regex data:image/.+ notificationEmail (str) – If set, change the service notification email address. caseTypesToAdd (list) – If set, enable the requested case type for this service. caseTypesToRemove (list) – If set, disable the requested case type for this service. This will be rejected if any non-deleted cases exist which are bound to this service and casetype. caseTypesToSet (list) – If set, override existing case types for this service. If this causes the service to remove a case type which has non-deleted cases bound to it, this will be rejected. readFunction (str) – If set, change the READ function for this service, identified by function ID or shortname. writeFunction (str) – If set, change the WRITE function for this service, identified by function ID or shortname. techFunction (str) – If set, change the TECH function for this service, identified by function ID or shortname. adminFunction (str) – If set, change the ADMIN function for this service, identified by function ID or shortname. defineFunction (str) – If set, change the DEFINE function for this service, identified by function ID or shortname. fieldPolicy (str) – If set, change the field policy for this service. Changing the field policy will affect new cases and future updates to existing cases, but will not change fields set on existing cases. notifyOnCreate (bool) – If set, change settings for notifying the service notification email address on created cases. notifyOnUpdate (bool) – If set, change settings for notifying the service notification email address on updated cases. notifyOnClose (bool) – If set, change settings for notifying the service notification email address on closed cases. notifyFullFormat (bool) – If set, change the format settings for notifying to the service notification email. handledBySoc (bool) – If set, set whether this service is handled by SOC 24/7. monitoredBySocOutsideOfficeHours (bool) – If set, set whether this service is monitored by SOC outside office hours.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 288, “limit”: 149, “responseCode”: 200, “count”: 33, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “However learn key matter.”, “messageTemplate”: “Likely choose scene education police possible.”, “field”: “Pass five thousand character.”, “parameter”: {}, “timestamp”: 362750345}], “currentPage”: 542, “size”: 692}

## api.cases.v2.servicesubscription module

Autogenerated API

`api.cases.v2.servicesubscription.` `add_customer_service_subscription`(customer: str = None, service: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Subscribe a customer to a service (INTERNAL)

  Return type: | `dict`
  Parameters: | customer (str) – Shortname or ID of customer to subscribe for service (str) – Shortname or ID of service to subscribe to
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 586, “limit”: 978, “responseCode”: 200, “count”: 991, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Relationship modern argue actually then.”, “messageTemplate”: “Traditional real company think.”, “field”: “Process arrive them evidence smile three or.”, “parameter”: {}, “timestamp”: 1090378908}], “currentPage”: 606, “size”: 277}

`api.cases.v2.servicesubscription.` `delete_customer_service_subscription`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove service subscription (INTERNAL)

  Return type: | `dict`
  Parameters: | id (str) – Subscription ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 368, “limit”: 147, “responseCode”: 200, “count”: 514, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “It specific recent agreement.”, “messageTemplate”: “Certain provide old heavy test cause first.”, “field”: “Game participant civil education in call reason least.”, “parameter”: {}, “timestamp”: 133993615}], “currentPage”: 361, “size”: 960}

`api.cases.v2.servicesubscription.` `list_subscriptions`(customerID: list = None, service: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List service subscriptions (INTERNAL)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit result to specified list of customers (by id) service (list) – Limit result to specified list of services (by id or shortname) offset (int) – Skip a number of results limit (int) – Maximum number of returned results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 846, “limit”: 675, “responseCode”: 200, “count”: 272, “data”: [{“id”: “Whatever him to several.”, “createdTimestamp”: 1309801048, “createdByUser”: {“id”: 489, “customerID”: 562, “userName”: “peterherrera”, “name”: “David Murphy”}, “lastUpdatedTimestamp”: 95224385, “lastUpdatedByUser”: {“id”: 700, “customerID”: 475, “userName”: “paul04”, “name”: “Veronica Barber”}, “flags”: [“DELETED”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Chair art day second attorney discover.”, “messageTemplate”: “Student analysis job know technology.”, “field”: “Enjoy despite common keep seem.”, “parameter”: {}, “timestamp”: 1007698756}], “currentPage”: 577, “size”: 523}

## Module contents